@@ -5,5 +5,11 @@ class CourseAdmin(admin.ModelAdmin):
     list_display = ('name', 'ctype', 'dept', 'teacher')
     search_fields = ('name', 'ctype', 'dept', 'teacher')
 
+class CommentAdmin(admin.ModelAdmin):
+    list_display = ('course', 'author', 'emotion')
+    search_fields = ('raw', )
+
 admin.site.register(Course, CourseAdmin)
-admin.site.register(Comment)
\ No newline at end of file
+admin.site.register(Comment, CommentAdmin)
+admin.site.register(LikesFromUser)
+admin.site.register(PageLog)
\ No newline at end of file
